/******************************************************************************

Copyright(c) 2020 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*******************************************************************************/

#ifndef ADSPSC59X_INIT_CONFIG_H
#define ADSPSC59X_INIT_CONFIG_H

#include "mem_types.h"

/* Define any non-default configuration macros here
 * and then delete the #error.
 */

/*Common macros*/
#if defined (__ADSPSC598W__) || defined (__ADSPSC598__) || defined (__ADSPSC596W__) || defined (__ADSPSC596__)
#define CONFIG_SHARC_CORE_CLOCK  (SHARC_CORE_CLOCK_1GHZ) /*!< SHARC Core Clock frequency */
#elif defined (__ADSPSC595W__) || defined (__ADSPSC595__)
#define CONFIG_SHARC_CORE_CLOCK  (SHARC_CORE_CLOCK_800MHZ) /*!< SHARC Core Clock frequency */
#endif
#define CLKIN   (25000000)               /*!< SYS_CLKIN value*/
#define CLKIN   (25000000)               /*!< SYS_CLKIN value*/
#define CONFIG_DMC0 (DDR3_8Gb) /*!< Define as 0, if there is no DDR on the board or the chip*/
#define CONFIG_SPIFLASH (1)              /*!< Define as 0, if there is no SPI Flash on the board or the chip*/
#define EXECUTE_SAFE_STATE (1)           /*!< Define as 1, if the program must go in to a safe state up on errors in the API calls*/
#define INIT_CANFD (1)                   /*!< Define to 1 for parts that have CANFD*/
/*Boot related macros*/
#define CONFIG_BOOT_UART_BAUD_RATE (0)   /*!< Define as 1, if the UART Baud Rate need to be recalculated and reinitialized*/
#define CONFIG_BOOT_SPI_CLOCK_RATE (0)   /*!< Define as 1, if the SPI Clock Rate need to be recalculated and reinitialized*/
#define CONFIG_BOOT_OSPI_CLOCK_RATE (0)  /*!< Define as 1, if the OSPI Clock Rate need to be recalculated and reinitialized*/
#define DO_PROCESS_BOOTSTRUCT (0)        /*!< Define as 1, if there is need to process the boot struct passed by ROM*/


/* SHARC Core clock macros */
#define SHARC_CORE_CLOCK_1GHZ (0)
#define SHARC_CORE_CLOCK_800MHZ (1)
#define SHARC_CORE_CLOCK_600MHZ (2)

/* DDR Clock Frequency macros */
#define DDR_CLOCK_667MHZ (1)
#define DDR_CLOCK_600MHZ (2)

#if CONFIG_SHARC_CORE_CLOCK == SHARC_CORE_CLOCK_1GHZ || CONFIG_SHARC_CORE_CLOCK == SHARC_CORE_CLOCK_600MHZ
#define CONFIG_DDR_CLOCK  (DDR_CLOCK_667MHZ) /*!< DDR Clock frequency */
#elif CONFIG_SHARC_CORE_CLOCK == SHARC_CORE_CLOCK_800MHZ
#define CONFIG_DDR_CLOCK  (DDR_CLOCK_600MHZ) /*!< DDR Clock frequency */
#endif


#if CONFIG_SHARC_CORE_CLOCK == SHARC_CORE_CLOCK_1GHZ
#include "adi_pwr_SC598_Family_1GHz_config.h"
#elif CONFIG_SHARC_CORE_CLOCK == SHARC_CORE_CLOCK_800MHZ
#include "adi_pwr_SC598_Family_800MHz_config.h"
#elif CONFIG_SHARC_CORE_CLOCK == SHARC_CORE_CLOCK_600MHZ
#include "adi_pwr_SC598_Family_600MHz_config.h"
#endif

#if CONFIG_DDR_CLOCK == DDR_CLOCK_667MHZ
#include "adi_dmc_SC598_Family_667MHz_config.h"
#elif CONFIG_DDR_CLOCK == DDR_CLOCK_600MHZ
#include "adi_dmc_SC598_Family_600MHz_config.h"
#endif

#endif /* ADSPSC59X_INIT_CONFIG_H */
