/* Copyright (c) 2009, 2010, 2011, 2012 ARM Ltd.  All rights reserved.

 Portions Copyright (c) 2020-2021 Analog Devices, Inc. All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.
 3. The name of the company may not be used to endorse or promote
    products derived from this software without specific prior written
    permission.

 THIS SOFTWARE IS PROVIDED BY ARM LTD ``AS IS'' AND ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL ARM LTD BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */

#include "newlib.h"

/* ANSI concatenation macros.  */
#define CONCAT(a, b) CONCAT2(a, b)
#define CONCAT2(a, b) a ## b

#ifdef __USER_LABEL_PREFIX__
#define FUNCTION( name ) CONCAT (__USER_LABEL_PREFIX__, name)
#else
#error __USER_LABEL_PREFIX is not defined
#endif

#ifdef HAVE_INITFINI_ARRAY
#define _init	__libc_init_array
#define _fini	__libc_fini_array
#endif

	.text
	.align	2

	.global _mainCRTStartup1
_mainCRTStartup1:
	.global _start1
_start1:
//*pREG_PORTB_FER_CLR = (1 << 4);
	//mov     x0, #0x4088                     // #16520
	//movk    x0, #0x3100, lsl #16
	//mov     w1, #0x10                       // #16
	//str     w1, [x0]
// *pREG_PORTB_DIR_SET = (1 << 4);
	//mov     x0, #0x409c                     // #16540
	//movk    x0, #0x3100, lsl #16
	//mov     w1, #0x10                       // #16
	//str     w1, [x0]
//*pREG_PORTB_DATA_CLR = (1 << 4);
	mov     x0, #0x4094                     // #16532
	movk    x0, #0x3100, lsl #16
	mov     w1, #0x10                       // #16
	str     w1, [x0]

        /*Enable DDR PFB*/
    ldr x0,=0x31076000
    mov w1, #0x1
    str w1,[x0]
    isb

	/* Start by setting up stacks */

	/* First set up the EL3 stack for the interrupts */
	ldr	x1, .Lstack3 /* Set up the EL3 stack pointer to a fixed value */
	and	x0, x1, #~15 /* Ensure quad-word stack alignment.  */
	msr	SPSel, #1    /* Use SP_EL3 for stack so we can set it */
	mov	sp, x0

	/* Set up an initial dummy frame with saved fp=0 and saved lr=0 */
	mov	x29, 0
	stp	x29, x29, [sp, #-16]!

	/* Now set up the EL0 stack for the application */
	ldr	x1, .Lstack0 /* Set up the EL0 stack pointer to a fixed value */
	and	x0, x1, #~15 /* Ensure quad-word stack alignment.  */
	msr 	SPSel, #0    /* Use SP_EL0 for stack at application level */
	mov	sp, x0

	/* Set up an initial dummy frame with saved fp=0 and saved lr=0 */
	mov	x29, 0
	stp	x29, x29, [sp, #-16]!
	mov	x29, sp

	/* Zero the memory in the .bss section.
	   We don't use memset, as we need to have set up the MMU first. */
	ldr	x0, .LC1		/* Start of bss section */
	ldr	x1, .LC2		/* End of bss section */
	cmp 	x0, x1
	bhs 	.Lpost_memset
.Lmemset_loop:
	strb 	wzr, [x0], 1
	cmp 	x0, x1
	bne 	.Lmemset_loop
.Lpost_memset:

	/* Call adi_cache_Init() API to configure caches. */
	bl 	FUNCTION (adi_cache_Init)  /* Unconditionally returns success */

	/* Initialize page tables and the Memory Management Unit (MMU). */
	bl 	FUNCTION (adi_mmu_Init)

	/* Set up the vector tables and exception handlers. */
	bl 	FUNCTION (adi_InitExceptionHandlers)

	/* .init and .fini sections are used to create constructors
	   and destructors.  Here we call the _init function and arrange
	   for _fini to be called at program exit.  */
	ldr	x0, .Lfini
	bl	FUNCTION (atexit)

	bl	FUNCTION (_init)

	mov	x0, #0	/* argc = 0 */
	mov	x1, #0	/* argv = NULL */

	bl	FUNCTION (main)

	b	FUNCTION (exit)		/* Cannot return.  */


/* Include references to the stack objects so that they are linked into the application */
	.dword __adi_stack_el0_object
	.dword __adi_stack_el3_object

	.align 3
.Lstack0:
	.dword __stack_el0_start // defined in the .ld file
.Lstack3:
	.dword __stack_el3_start // defined in the .ld file

.LC1:
	.dword __bss_start__
.LC2:
	.dword __bss_end__
.Lfini:
	.dword FUNCTION(_fini)
