/* 
 * Copyright (c) 1994-2009, Red Hat, Inc. All rights reserved.
 *
 * Portions Copyright (c) 2021-2023 Analog Devices, Inc. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 * contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

/* This file is copied into your project by the Linker Files Add-In.
 * The default target for code and data is L3 memory. Please modify it
 * as required for your project.
 *
 * If you change settings within the Linker Files Add-In, the file will
 * be regenerated, and your modified copy will be preserved with the
 * .backup file extension.
 *
 * This file was created by CrossCore Embedded Studio 2.12.0 for ADSP-SC598.
 */

/*
 * IMPORTANT:
 *
 *   The default distribution of L2 and L3 memory between the ARM and
 *   the SHARC cores is chosen to give similar amounts of memory to each
 *   core. However, the memory requirements in your application for the
 *   ARM and SHARC cores may not be equal. In addition, the L3 memory
 *   allocated is that which is available on the EV-SC598 SOM board.
 *
 *   If you have a different amount of L3 memory, or change the distribution
 *   of L2 or L3 memory between the cores, please note that these changes must
 *   also be reflected in the LDF files for your SHARC projects, and in
 *   the Abstract Page Table used for your ARM project.
 */

MEMORY
{
  /* #### SHARED L2 Memory ############################################### */
  /* MCAPI ICC Data, uncached */
  MEM_L2_MCAPI_DATA_ICC : ORIGIN = 0x20000000, LENGTH = 4K

  /* MCAPI Buffer ARM Core 0, uncached */
  MEM_L2_MCAPI_DATA_CORE0 : ORIGIN = 0x20001000, LENGTH = 16K

  /* MCAPI Buffer SHARC Core 2, uncached */
  MEM_L2_MCAPI_DATA_CORE2 (r) : ORIGIN = 0x20005000, LENGTH = 64K

  /* MCAPI Buffer SHARC Core 1, uncached */
  MEM_L2_MCAPI_DATA_CORE1 (r) : ORIGIN = 0x20015000, LENGTH = 64K

  /* #### ARM L2 Memory ################################################## */

  /* ARM Core 0 L2 RAM, uncached */
  MEM_L2_UNCACHED : ORIGIN = 0x20025000, LENGTH = 108K

  /* ARM Core 0 L2 RAM, cached */
  MEM_L2_CACHED : ORIGIN = 0x20040000, LENGTH = 768K

  /* #### SHARC L2 Memory ################################################ */
  /* SHARC Core 2 L2 RAM, cached */
  MEM_L2_CORE2 (r) : ORIGIN = 0x20100000, LENGTH = 512K

  /* SHARC Core 1 L2 RAM, cached */
  MEM_L2_CORE1 (r) : ORIGIN = 0x20180000, LENGTH = 512K

  /* #### SHARC L3 Memory ################################################ */

  /* SHARC Core 1 NW Code, DMC0 */
  MEM_L3_CORE1_NW_CODE (r) : ORIGIN = 0x80000000, LENGTH = 3M

  /* SHARC Core 2 NW Code, DMC0 */
  MEM_L3_CORE2_NW_CODE (r) : ORIGIN = 0x80300000, LENGTH = 3M

  /* SHARC Core 1 Data, DMC0 */
  MEM_L3_CORE1_DATA (r) : ORIGIN = 0x80600000, LENGTH = 4M

  /* SHARC Core 1 VISA Code, DMC0 */
  MEM_L3_CORE1_VISA_CODE (r) : ORIGIN = 0x80A00000, LENGTH = 3M

  /* SHARC Core 2 VISA Code, DMC0 */
  MEM_L3_CORE2_VISA_CODE (r) : ORIGIN = 0x80D00000, LENGTH = 3M

  /* SHARC Core 1 Data, DMC0 */
  MEM_L3_CORE1_DATA2 (r) : ORIGIN = 0x81000000, LENGTH = 118M

  /* SHARC Core 2 Data, DMC0 */
  MEM_L3_CORE2_DATA2 (r) : ORIGIN = 0x88600000, LENGTH = 122M

  /* #### ARM L3 Memory ################################################## */

  /* ARM Core 0 L3, DMC0 */
  MEM_L3 : ORIGIN = 0x90000000, LENGTH = 256M

}

SECTIONS {
  __MCAPI_common_start = ORIGIN(MEM_L2_MCAPI_DATA_ICC) ;
  __MCAPI_common_end   = ORIGIN(MEM_L2_MCAPI_DATA_ICC) + LENGTH(MEM_L2_MCAPI_DATA_ICC) - 1 ;
  __MCAPI_arm_start = ORIGIN(MEM_L2_MCAPI_DATA_CORE0) ;
  __MCAPI_arm_end   = ORIGIN(MEM_L2_MCAPI_DATA_CORE0) + LENGTH(MEM_L2_MCAPI_DATA_CORE0) - 1 ;
  __MCAPI_sharc0_start = ORIGIN(MEM_L2_MCAPI_DATA_CORE1) ;
  __MCAPI_sharc0_end   = ORIGIN(MEM_L2_MCAPI_DATA_CORE1) + LENGTH(MEM_L2_MCAPI_DATA_CORE1) - 1 ;
  __MCAPI_sharc1_start = ORIGIN(MEM_L2_MCAPI_DATA_CORE2) ;
  __MCAPI_sharc1_end   = ORIGIN(MEM_L2_MCAPI_DATA_CORE2) + LENGTH(MEM_L2_MCAPI_DATA_CORE2) - 1 ;
  __l2_start = 0x20000000 ;
  __l2_end = 0x201FFFFF ;
  __l2_uncached_start = ORIGIN(MEM_L2_MCAPI_DATA_CORE0) ;
  __l2_uncached_end = ORIGIN(MEM_L2_UNCACHED) + LENGTH(MEM_L2_UNCACHED) - 1 ;
  __l2_cached_start = ORIGIN(MEM_L2_CACHED) ;
  __l2_cached_end = ORIGIN(MEM_L2_CORE1) + LENGTH(MEM_L2_CORE1) - 1 ;
}

OUTPUT_ARCH(aarch64)
OUTPUT_FORMAT(elf64-littleaarch64)
ENTRY(_start)
/* Do we need any of these for elf?
   __DYNAMIC = 0;    */
SECTIONS
{
  /* Read-only sections, merged into text segment: */
  .interp     : { *(.interp) 	}
  .hash          : { *(.hash)		}
  .dynsym        : { *(.dynsym)		}
  .dynstr        : { *(.dynstr)		}
  .gnu.version   : { *(.gnu.version)	}
  .gnu.version_d   : { *(.gnu.version_d)	}
  .gnu.version_r   : { *(.gnu.version_r)	}
  .rel.init      : { *(.rel.init)	}
  .rela.init     : { *(.rela.init)	}
  .rel.text      :
    {
      *(.rel.text)
      *(.rel.text.*)
      *(.rel.gnu.linkonce.t*)
    }
  .rela.text     :
    {
      *(.rela.text)
      *(.rela.text.*)
      *(.rela.gnu.linkonce.t*)
    }
  .rel.fini      : { *(.rel.fini)	}
  .rela.fini     : { *(.rela.fini)	}
  .rel.rodata    :
    {
      *(.rel.rodata)
      *(.rel.rodata.*)
      *(.rel.gnu.linkonce.r*)
    }
  .rela.rodata   :
    {
      *(.rela.rodata)
      *(.rela.rodata.*)
      *(.rela.gnu.linkonce.r*)
    }
  .rel.data      :
    {
      *(.rel.data)
      *(.rel.data.*)
      *(.rel.gnu.linkonce.d*)
    }
  .rela.data     :
    {
      *(.rela.data)
      *(.rela.data.*)
      *(.rela.gnu.linkonce.d*)
    }
  .rel.ctors     : { *(.rel.ctors)	}
  .rela.ctors    : { *(.rela.ctors)	}
  .rel.dtors     : { *(.rel.dtors)	}
  .rela.dtors    : { *(.rela.dtors)	}
  .rel.got       : { *(.rel.got)		}
  .rela.got      : { *(.rela.got)		}
  .rel.sdata     :
    {
      *(.rel.sdata)
      *(.rel.sdata.*)
      *(.rel.gnu.linkonce.s*)
    }
  .rela.sdata     :
    {
      *(.rela.sdata)
      *(.rela.sdata.*)
      *(.rela.gnu.linkonce.s*)
    }
  .rel.sbss      : { *(.rel.sbss)		}
  .rela.sbss     : { *(.rela.sbss)	}
  .rel.bss       : { *(.rel.bss)		}
  .rela.bss      : { *(.rela.bss)		}
  .rel.plt       : { *(.rel.plt)		}
  .rela.plt      : { *(.rela.plt)		}
  .plt      : { *(.plt)	}
  /* L2 uncached section:
  ** Place any objects required to be uncached. */
  .l2_uncached :
  {
    *(.l2_uncached_crt)
    *(.l2_uncached_code)
    *(.l2_uncached_data)
  } >MEM_L2_UNCACHED = 0

  /* L2 cached section:
  ** Place any objects explicitly required to be cached in L2. */
  .l2_cached :
  {
    *(.l2_cached_crt)
    *(.l2_cached_code)
    *(.l2_cached_data)
  } >MEM_L2_CACHED = 0

  /* L3 MMU table section:
  ** Place page_table_mem.o at the start of L3 to avoid large amounts
  ** of padding to meet the _adi_mmu_tableMemory 4kB alignment */
  .l3_mmu_table (NOLOAD) :
  {
    *page_table_mem.o(.bss .bss*)
  } >MEM_L3 = 0

  /* L3 Memory. No code/data placed here by default */
  .l3 :
  {
    *(.l3_code)
    *(.l3_data)
  } >MEM_L3 = 0

  /* MMU Configuration data */
  .mmu_config :
  {
    KEEP (*(.mmu_config))
  } >MEM_L3 = 0

  /* Heap object */
  .heap (NOLOAD) :
  {
    __heap_start = . ;
    *(.heap)
    __heap_end = . ;
    __heap_limit = . ;
  } >MEM_L3 = 0

  /* Exception Level 0 stack */
  .stack_el0 (NOLOAD) :
  {
    __stack_el0_end = . ;
    KEEP(*(.stack_el0))
    __stack_el0_start = . ;
  } > MEM_L2_CACHED = 0

  /* Exception Level 3 stack */
  .stack_el3 (NOLOAD) :
  {
    __stack_el3_end = . ;
    KEEP(*(.stack_el3))
    __stack_el3_start = . ;
  } > MEM_L2_CACHED = 0

  /* MCAPI section:
     Only declare sections that are writeable by the ARM
     core.  */
  .mcapi_data_icc   :
  {
    *(.mcapi_data_icc)  
  } >MEM_L2_MCAPI_DATA_ICC

  .mcapi_data_core0   :
  {
    *(.mcapi_data_core0)
  } >MEM_L2_MCAPI_DATA_CORE0

  .text      :
  {
    *(.text)
    *(.text.*)
    *(.stub)
    /* .gnu.warning sections are handled specially by elf32.em.  */
    *(.gnu.warning)
    *(.gnu.linkonce.t*)
    *(.glue_7t) *(.glue_7)
  } >MEM_L3 =0
  .init          : 
  { 
    KEEP (*(.init))
  } >MEM_L3 =0
  _etext = .;
  PROVIDE (etext = .);
  .fini      :
  {
    KEEP (*(.fini))
  } >MEM_L3 =0
  .rodata   : { *(.rodata) *(.rodata.*) *(.gnu.linkonce.r*) } >MEM_L3 =0
  .rodata1   : { *(.rodata1) } >MEM_L3 =0
  .eh_frame_hdr : { *(.eh_frame_hdr) } >MEM_L3 =0
  .ARM.extab   : { *(.ARM.extab*  .gnu.linkonce.armextab.*) } >MEM_L3 =0
  .ARM.exidx   : {
    __exidx_start = .;
    *(.ARM.exidx* .gnu.linkonce.armexidx.*)
    __exidx_end = .;
  } >MEM_L3 =0
  /* Adjust the address for the data segment.  We want to adjust up to
     the same address within the page on the next page up.  */
  . = ALIGN(256) + (. & (256 - 1));
  .data    :
  {
    *(.data)
    *(.data.*)
    *(.gnu.linkonce.d*)
    SORT(CONSTRUCTORS)
  } >MEM_L3 =0
  .data1   : { *(.data1) } >MEM_L3 =0
  .eh_frame : { KEEP (*(.eh_frame)) } >MEM_L3 =0
  .gcc_except_table : { *(.gcc_except_table) } >MEM_L3 =0
  .preinit_array     :
  {
    PROVIDE_HIDDEN (__preinit_array_start = .);
    KEEP (*(.preinit_array))
    PROVIDE_HIDDEN (__preinit_array_end = .);
  } >MEM_L3 =0
  .init_array     :
  {
     PROVIDE_HIDDEN (__init_array_start = .);
     KEEP (*(SORT(.init_array.*)))
     KEEP (*(.init_array))
     PROVIDE_HIDDEN (__init_array_end = .);
  } >MEM_L3 =0
  .fini_array     :
  {
    PROVIDE_HIDDEN (__fini_array_start = .);
    KEEP (*(.fini_array))
    KEEP (*(SORT(.fini_array.*)))
    PROVIDE_HIDDEN (__fini_array_end = .);
  } >MEM_L3 =0
  .ctors   : 
  {
    /* gcc uses crtbegin.o to find the start of
       the constructors, so we make sure it is
       first.  Because this is a wildcard, it
       doesn't matter if the user does not
       actually link against crtbegin.o; the
       linker won't look for a file to match a
       wildcard.  The wildcard also means that it
       doesn't matter which directory crtbegin.o
       is in.  */
    KEEP (*crtbegin.o(.ctors))
    /* We don't want to include the .ctor section from
       from the crtend.o file until after the sorted ctors.
       The .ctor section from the crtend file contains the
       end of ctors marker and it must be last */
    KEEP (*(EXCLUDE_FILE (*crtend.o ) .ctors))
    KEEP (*(SORT(.ctors.*)))
    KEEP (*(.ctors))
  } >MEM_L3 =0
   .dtors         :
  {
    KEEP (*crtbegin.o(.dtors))
    KEEP (*(EXCLUDE_FILE (*crtend.o ) .dtors))
    KEEP (*(SORT(.dtors.*)))
    KEEP (*(.dtors))
  } >MEM_L3 =0
  .jcr           : { KEEP (*(.jcr)) } >MEM_L3 =0
  .got           : { *(.got.plt) *(.got) } >MEM_L3 =0
  .dynamic       : { *(.dynamic) } >MEM_L3 =0
  /* We want the small data sections together, so single-instruction offsets
     can access them all, and initialized data all before uninitialized, so
     we can shorten the on-disk segment size.  */
  .sdata     : 
  {
    *(.sdata) 
    *(.sdata.*)
    *(.gnu.linkonce.s.*)
  } >MEM_L3 =0
  _edata = .;
  PROVIDE (edata = .);
  __bss_start = .;
  __bss_start__ = .;
  .sbss      :
  {
    *(.dynsbss)
    *(.sbss)
    *(.sbss.*)
    *(.scommon)
  } >MEM_L3 =0
  .bss       :
  {
   *(.dynbss)
   *(.bss)
   *(.bss.*)
   *(COMMON)
   /* Align here to ensure that the .bss section occupies space up to
      _end.  Align after .bss to ensure correct alignment even if the
      .bss section disappears because there are no input sections.  */
   . = ALIGN(32 / 8);
  } >MEM_L3 =0
  _bss_end__ = . ; __bss_end__ = . ;
  PROVIDE(_end = .);

  /* DWARF debug sections.
     Symbols in the DWARF debugging sections are relative to the beginning
     of the section so we begin them at 0.  */
  /* DWARF 1 */
  .debug          0 : { *(.debug) }
  .line           0 : { *(.line) }
  /* GNU DWARF 1 extensions */
  .debug_srcinfo  0 : { *(.debug_srcinfo) }
  .debug_sfnames  0 : { *(.debug_sfnames) }
  /* DWARF 1.1 and DWARF 2 */
  .debug_aranges  0 : { *(.debug_aranges) }
  .debug_pubnames 0 : { *(.debug_pubnames) }
  /* DWARF 2 */
  .debug_info     0 : { *(.debug_info) }
  .debug_abbrev   0 : { *(.debug_abbrev) }
  .debug_line     0 : { *(.debug_line) }
  .debug_frame    0 : { *(.debug_frame) }
  .debug_str      0 : { *(.debug_str) }
  .debug_loc      0 : { *(.debug_loc) }
  .debug_macinfo  0 : { *(.debug_macinfo) }
  .debug_ranges   0 : { *(.debug_ranges) }
  /* SGI/MIPS DWARF 2 extensions */
  .debug_weaknames 0 : { *(.debug_weaknames) }
  .debug_funcnames 0 : { *(.debug_funcnames) }
  .debug_typenames 0 : { *(.debug_typenames) }
  .debug_varnames  0 : { *(.debug_varnames) }
}
